import React, {
  useRef,
  useEffect,
  useState,
  useCallback,
  useMemo,
} from "react";
import { Link } from "wouter";
import { motion } from "framer-motion";
import { Button } from "@/components/ui/button";
import { useTheme } from "@/contexts/ThemeContext";
import ProfileImage from "./ProfileImage";

// --- Configuration ---
const DESKTOP_NUM_NODES = 35; // Reduced from 50 for better performance
const TABLET_NUM_NODES = 20; // Reduced from 30 for better performance
const MOBILE_NUM_NODES = 10; // Reduced from 15 for better performance
const CONNECTION_RADIUS = 180; // Increased from 120 to create more connections between nodes
const MOUSE_REPULSION_RADIUS = 100;
const MOUSE_REPULSION_STRENGTH = 0.5;
const BASE_PULL_STRENGTH = 0.001; // Gravity towards original position
const MAX_SPEED = 1;
const FRICTION = 0.98;
// New configuration for performance with better user experience
const NODE_UPDATE_INTERVAL = 16; // ms between node position updates (60 FPS)
const CONNECTION_UPDATE_INTERVAL = 50; // ms between connection updates (reduced from 150ms for smoother connections)
const AUTO_ANIMATION_STRENGTH = 0.2; // Constant animation strength when mouse is not moving

// --- Hooks ---

// Hook to get window dimensions
const useWindowSize = () => {
  const [size, setSize] = useState([0, 0]); // Initialize with 0 to prevent SSR issues if used
  useEffect(() => {
    const getSize = () => [window.innerWidth, window.innerHeight];
    setSize(getSize()); // Set initial size
    const handleResize = () => setSize(getSize());
    window.addEventListener("resize", handleResize);
    return () => window.removeEventListener("resize", handleResize);
  }, []);
  return size;
};

// Hook for mouse position relative to an element
const useMousePosition = (ref: React.RefObject<Element>) => {
  const [mousePosition, setMousePosition] = useState<{
    x: number | null;
    y: number | null;
  }>({ x: null, y: null });

  useEffect(() => {
    const updateMousePosition = (ev: MouseEvent) => {
      if (ref.current) {
        const rect = ref.current.getBoundingClientRect();
        setMousePosition({
          x: ev.clientX - rect.left,
          y: ev.clientY - rect.top,
        });
      } else {
        setMousePosition({ x: ev.clientX, y: ev.clientY }); // Fallback to window coords if ref not ready
      }
    };
    const resetMousePosition = () => {
      setMousePosition({ x: null, y: null });
    };

    // Attach listener to window initially
    window.addEventListener("mousemove", updateMousePosition);
    // Use mouseleave on the target element if available
    const currentRef = ref.current;
    if (currentRef) {
      currentRef.addEventListener("mouseleave", resetMousePosition);
    }

    return () => {
      window.removeEventListener("mousemove", updateMousePosition);
      if (currentRef) {
        currentRef.removeEventListener("mouseleave", resetMousePosition);
      }
    };
    // Don't use ref.current in the dependency array, use ref instead
  }, [ref]); // Depend on the ref itself, not its current value

  return mousePosition;
};

// --- Types ---
interface Node {
  id: number;
  x: number;
  y: number;
  vx: number; // velocity x
  vy: number; // velocity y
  radius: number;
  baseX: number; // Original position
  baseY: number; // Original position
}

interface Connection {
  id: string;
  node1Id: number;
  node2Id: number;
}

// --- Main Component ---

const Hero: React.FC = () => {
  const { theme } = useTheme();
  const heroRef = useRef<HTMLDivElement>(null);
  const svgRef = useRef<SVGSVGElement>(null);
  const nodesRef = useRef<Node[]>([]); // Use ref to keep stable reference for animation loop
  const [connections, setConnections] = useState<Connection[]>([]);
  const [viewportWidth, viewportHeight] = useWindowSize(); // Use dynamic dimensions
  const mousePos = useMousePosition(svgRef); // Track mouse within SVG bounds
  const [renderTrigger, setRenderTrigger] = useState(0); // State to trigger re-render

  // Dynamically determine number of nodes based on screen width
  const NUM_NODES = useMemo(() => {
    if (viewportWidth < 640) {
      // Mobile devices
      return MOBILE_NUM_NODES;
    } else if (viewportWidth < 1024) {
      // Tablets
      return TABLET_NUM_NODES;
    } else {
      // Desktops
      return DESKTOP_NUM_NODES;
    }
  }, [viewportWidth]);

  const nodesInitialized = useRef(false);

  // Track previous screen width category to detect major size changes
  const prevScreenCategory = useRef<"mobile" | "tablet" | "desktop">(
    viewportWidth < 640
      ? "mobile"
      : viewportWidth < 1024
        ? "tablet"
        : "desktop",
  );

  // Initialize nodes
  useEffect(() => {
    // Get current screen category
    const currentCategory =
      viewportWidth < 640
        ? "mobile"
        : viewportWidth < 1024
          ? "tablet"
          : "desktop";

    // Force reinitialization if screen category changed (e.g. mobile -> desktop)
    if (currentCategory !== prevScreenCategory.current) {
      nodesInitialized.current = false;
      prevScreenCategory.current = currentCategory;
    }

    if (nodesInitialized.current || viewportWidth === 0 || viewportHeight === 0)
      return;

    // Define a "safe zone" in the center where we don't want dots
    const centerX = viewportWidth / 2;
    const centerY = viewportHeight / 2;
    const safeZoneWidth = Math.min(viewportWidth * 0.6, 800); // Limit width of safe zone
    const safeZoneHeight = Math.min(viewportHeight * 0.7, 600); // Limit height of safe zone

    const safeZoneLeft = centerX - safeZoneWidth / 2;
    const safeZoneRight = centerX + safeZoneWidth / 2;
    const safeZoneTop = centerY - safeZoneHeight / 2;
    const safeZoneBottom = centerY + safeZoneHeight / 2;

    // Function to check if a point is within the safe zone
    const isInSafeZone = (x: number, y: number) => {
      return (
        x > safeZoneLeft &&
        x < safeZoneRight &&
        y > safeZoneTop &&
        y < safeZoneBottom
      );
    };

    const newNodes: Node[] = [];
    for (let i = 0; i < NUM_NODES; i++) {
      let x = Math.random() * viewportWidth;
      let y = Math.random() * viewportHeight;

      // If point is in safe zone, move it outside
      if (isInSafeZone(x, y)) {
        // Choose a random edge to place the node
        const edge = Math.floor(Math.random() * 4); // 0: top, 1: right, 2: bottom, 3: left

        switch (edge) {
          case 0: // top
            y = Math.random() * safeZoneTop;
            break;
          case 1: // right
            x = safeZoneRight + Math.random() * (viewportWidth - safeZoneRight);
            break;
          case 2: // bottom
            y =
              safeZoneBottom +
              Math.random() * (viewportHeight - safeZoneBottom);
            break;
          case 3: // left
            x = Math.random() * safeZoneLeft;
            break;
        }
      }

      newNodes.push({
        id: i,
        x: x,
        y: y,
        vx: (Math.random() - 0.5) * 0.5, // Slower initial velocity
        vy: (Math.random() - 0.5) * 0.5,
        radius: Math.random() * 6 + 4, // Quadrupled node size (was originally 1.5 + 1)
        baseX: x,
        baseY: y,
      });
    }
    nodesRef.current = newNodes;
    nodesInitialized.current = true;
    setRenderTrigger((prev) => prev + 1); // Trigger initial render of nodes
    console.log("Nodes initialized:", newNodes.length);

    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [viewportWidth, viewportHeight, NUM_NODES]); // Reinitialize if viewport size or number of nodes changes

  // Store state update flags at ref level to avoid state updates triggering rerenders
  // Defined outside useEffect to maintain reference across renders
  const updateFlagsRef = useRef({
    nodesChanged: false,
    connectionsChanged: false,
  });

  // Update node positions and connections in an animation loop
  useEffect(() => {
    if (!nodesInitialized.current) return;

    let animationFrameId: number;
    let lastNodeUpdateTime = 0;
    let lastConnectionUpdateTime = 0;

    const update = (timestamp: number) => {
      // Delay intensive animations to improve LCP
      const isInitialLoad = timestamp < 3000; // First 3 seconds considered initial load

      // Throttle node updates for performance - more aggressively during initial load
      const nodeUpdateInterval = isInitialLoad
        ? NODE_UPDATE_INTERVAL * 3
        : NODE_UPDATE_INTERVAL;
      const shouldUpdateNodes =
        timestamp - lastNodeUpdateTime >= nodeUpdateInterval;

      // Throttle connection updates even more aggressively - especially during initial load
      const connectionUpdateInterval = isInitialLoad
        ? CONNECTION_UPDATE_INTERVAL * 4
        : CONNECTION_UPDATE_INTERVAL;
      const shouldUpdateConnections =
        timestamp - lastConnectionUpdateTime >= connectionUpdateInterval;

      if (!shouldUpdateNodes && !shouldUpdateConnections) {
        // Skip calculation completely if neither needs update
        animationFrameId = requestAnimationFrame(update);
        return;
      }

      const currentNodes = nodesRef.current;

      // Define center safe zone (same dimensions as in node initialization)
      const centerX = viewportWidth / 2;
      const centerY = viewportHeight / 2;
      const safeZoneWidth = Math.min(viewportWidth * 0.6, 800);
      const safeZoneHeight = Math.min(viewportHeight * 0.7, 600);

      const safeZoneLeft = centerX - safeZoneWidth / 2;
      const safeZoneRight = centerX + safeZoneWidth / 2;
      const safeZoneTop = centerY - safeZoneHeight / 2;
      const safeZoneBottom = centerY + safeZoneHeight / 2;

      // Function to check if a point is within the safe zone
      const isInSafeZone = (x: number, y: number) => {
        return (
          x > safeZoneLeft &&
          x < safeZoneRight &&
          y > safeZoneTop &&
          y < safeZoneBottom
        );
      };

      // --- Update Nodes (throttled) ---
      if (shouldUpdateNodes) {
        lastNodeUpdateTime = timestamp;
        updateFlagsRef.current.nodesChanged = false;

        currentNodes.forEach((node) => {
          let { x, y, vx, vy, baseX, baseY, radius } = node;
          const startX = x;
          const startY = y;

          // Boundary collision
          if (x - radius < 0) {
            vx = Math.abs(vx) * 0.9;
            x = radius;
          }
          if (x + radius > viewportWidth) {
            vx = -Math.abs(vx) * 0.9;
            x = viewportWidth - radius;
          }
          if (y - radius < 0) {
            vy = Math.abs(vy) * 0.9;
            y = radius;
          }
          if (y + radius > viewportHeight) {
            vy = -Math.abs(vy) * 0.9;
            y = viewportHeight - radius;
          }

          // Repel nodes from central "safe zone"
          if (isInSafeZone(x, y)) {
            // Determine closest edge to push towards
            const distToLeft = x - safeZoneLeft;
            const distToRight = safeZoneRight - x;
            const distToTop = y - safeZoneTop;
            const distToBottom = safeZoneBottom - y;

            // Find the closest edge
            const minDist = Math.min(
              distToLeft,
              distToRight,
              distToTop,
              distToBottom,
            );

            // Apply a repulsion force away from the center/towards the closest edge
            if (minDist === distToLeft) {
              vx -= 0.2; // Push left
            } else if (minDist === distToRight) {
              vx += 0.2; // Push right
            } else if (minDist === distToTop) {
              vy -= 0.2; // Push up
            } else if (minDist === distToBottom) {
              vy += 0.2; // Push down
            }
          }

          // Mouse interaction (repulsion)
          if (mousePos.x !== null && mousePos.y !== null) {
            const dx = x - mousePos.x;
            const dy = y - mousePos.y;
            const distSq = dx * dx + dy * dy; // Use squared distance for performance

            if (distSq < MOUSE_REPULSION_RADIUS * MOUSE_REPULSION_RADIUS) {
              const dist = Math.sqrt(distSq);
              const force =
                ((MOUSE_REPULSION_RADIUS - dist) / MOUSE_REPULSION_RADIUS) *
                MOUSE_REPULSION_STRENGTH;
              const angle = Math.atan2(dy, dx);
              vx += Math.cos(angle) * force;
              vy += Math.sin(angle) * force;
            }
          }

          // Gravity towards base position
          const dxBase = baseX - x;
          const dyBase = baseY - y;
          vx += dxBase * BASE_PULL_STRENGTH;
          vy += dyBase * BASE_PULL_STRENGTH;

          // Add constant movement even when mouse is not active
          // This ensures animation continues and connections remain visible
          vx +=
            Math.sin(timestamp * 0.001 + node.id) *
            AUTO_ANIMATION_STRENGTH *
            0.1;
          vy +=
            Math.cos(timestamp * 0.001 + node.id * 0.7) *
            AUTO_ANIMATION_STRENGTH *
            0.1;

          // Limit velocity
          const speedSq = vx * vx + vy * vy;
          if (speedSq > MAX_SPEED * MAX_SPEED) {
            const speed = Math.sqrt(speedSq);
            vx = (vx / speed) * MAX_SPEED;
            vy = (vy / speed) * MAX_SPEED;
          }

          // Apply friction
          vx *= FRICTION;
          vy *= FRICTION;

          // Update position
          x += vx;
          y += vy;

          // Update node object in the ref directly
          node.x = x;
          node.y = y;
          node.vx = vx;
          node.vy = vy;

          // Track if any node actually moved significantly
          if (Math.abs(startX - x) > 0.05 || Math.abs(startY - y) > 0.05) {
            // Increased threshold for significant movement
            updateFlagsRef.current.nodesChanged = true;
          }
        });
      }

      // --- Update Connections (heavily throttled) ---
      if (shouldUpdateConnections) {
        lastConnectionUpdateTime = timestamp;
        updateFlagsRef.current.connectionsChanged = false;

        // Use spatial partitioning to reduce checks
        // We'll use a simple grid-based approach
        const gridSize = CONNECTION_RADIUS;
        const grid: Map<string, Node[]> = new Map();

        // Place nodes in grid cells
        currentNodes.forEach((node) => {
          const cellX = Math.floor(node.x / gridSize);
          const cellY = Math.floor(node.y / gridSize);
          const cellKey = `${cellX},${cellY}`;

          if (!grid.has(cellKey)) {
            grid.set(cellKey, []);
          }
          grid.get(cellKey)!.push(node);
        });

        const newConnections: Connection[] = [];

        // Only check nodes in same or adjacent cells
        currentNodes.forEach((node1) => {
          const cellX = Math.floor(node1.x / gridSize);
          const cellY = Math.floor(node1.y / gridSize);

          // Check all adjacent cells including current
          for (let dx = -1; dx <= 1; dx++) {
            for (let dy = -1; dy <= 1; dy++) {
              const cellKey = `${cellX + dx},${cellY + dy}`;
              const cellNodes = grid.get(cellKey);

              if (cellNodes) {
                cellNodes.forEach((node2) => {
                  // Skip self or already processed pairs
                  if (node1.id >= node2.id) return;

                  const dx = node1.x - node2.x;
                  const dy = node1.y - node2.y;
                  const distSq = dx * dx + dy * dy;

                  if (distSq < CONNECTION_RADIUS * CONNECTION_RADIUS) {
                    newConnections.push({
                      id: `${node1.id}-${node2.id}`,
                      node1Id: node1.id,
                      node2Id: node2.id,
                    });
                  }
                });
              }
            }
          }
        });

        // Check if connections have changed
        const serializeConnections = (conns: Connection[]) =>
          conns
            .map((c) => c.id)
            .sort()
            .join(",");

        const newConnectionStr = serializeConnections(newConnections);
        const oldConnectionStr = serializeConnections(connections);

        if (newConnectionStr !== oldConnectionStr) {
          updateFlagsRef.current.connectionsChanged = true;
          setConnections(newConnections);
        }
      }

      // Only trigger re-render if nodes or connections have changed significantly
      if (
        updateFlagsRef.current.nodesChanged ||
        updateFlagsRef.current.connectionsChanged
      ) {
        setRenderTrigger((prev) => prev + 1);
      }

      animationFrameId = requestAnimationFrame(update);
    };

    // Start the animation loop
    animationFrameId = requestAnimationFrame(update);

    // Cleanup function
    return () => {
      console.log("Cancelling animation frame");
      cancelAnimationFrame(animationFrameId);
    };
    // Fixing dependency array to avoid invalid hook calls
  }, [viewportWidth, viewportHeight, mousePos, connections]); // Depend on external factors, not ref.current values

  // --- Dynamic SVG Styles ---
  const nodeColor =
    theme === "dark" ? "rgba(220, 200, 255, 0.9)" : "rgba(50, 30, 80, 0.9)"; // Increased opacity from 0.7 to 0.9
  const connectionColor =
    theme === "dark" ? "rgba(200, 180, 255, 0.8)" : "rgba(100, 80, 140, 0.8)"; // Increased opacity and brightness for better visibility

  // --- Framer Motion Variants ---
  const textContainerVariant = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: { staggerChildren: 0.2, delayChildren: 0.5 },
    },
  };

  const textItemVariant = {
    hidden: { y: 20, opacity: 0 },
    visible: {
      y: 0,
      opacity: 1,
      transition: { type: "spring", stiffness: 100, damping: 15 },
    },
  };

  // Memoize SVG elements if necessary, especially connections if they update rapidly
  const ConnectionLines = React.memo(
    ({ connections, nodes }: { connections: Connection[]; nodes: Node[] }) => {
      // Create a map for quick node lookup
      const nodeMap = new Map(nodes.map((n) => [n.id, n]));

      return (
        <g id="connections">
          {connections.map((conn) => {
            const node1 = nodeMap.get(conn.node1Id);
            const node2 = nodeMap.get(conn.node2Id);

            if (!node1 || !node2) return null; // Handle case where nodes might not be found (shouldn't happen)

            const dist = Math.sqrt(
              (node1.x - node2.x) ** 2 + (node1.y - node2.y) ** 2,
            );
            const opacity = Math.max(0, (1 - dist / CONNECTION_RADIUS) * 0.9); // Increased fade factor from 0.6 to 0.9

            return (
              <line // Use plain line for performance, animation handled by opacity
                key={conn.id}
                x1={node1.x}
                y1={node1.y}
                x2={node2.x}
                y2={node2.y}
                stroke={connectionColor}
                strokeWidth="2.5" /* Increased thickness for better visibility */
                opacity={opacity} // Control opacity directly
                // No framer motion here for performance
              />
            );
          })}
        </g>
      );
    },
  );
  ConnectionLines.displayName = "ConnectionLines"; // For React DevTools

  const Nodes = React.memo(({ nodes }: { nodes: Node[] }) => {
    return (
      <g id="nodes">
        {nodes.map((node) => (
          <circle // Use plain circle for performance
            key={node.id}
            cx={node.x}
            cy={node.y}
            r={node.radius}
            fill={nodeColor}
            // filter="url(#synapseGlow)" // Filter can be costly, enable if needed
          />
        ))}
      </g>
    );
  });
  Nodes.displayName = "Nodes"; // For React DevTools

  return (
    <section
      ref={heroRef}
      className={`relative min-h-[100vh] h-auto flex items-center justify-center overflow-hidden pt-24 pb-16 sm:pt-28 ${
        theme === "dark" ? "bg-gray-950" : "bg-gray-100" // Use darker/lighter background
      }`}
      // Trigger render based on state change
      data-render-trigger={renderTrigger}
      style={{ marginTop: "0px" }} /* Compensate for navbar */
    >
      {/* Background SVG for Synapse Network */}
      <svg
        ref={svgRef}
        width="100%"
        height="100%"
        className="absolute inset-0 z-0 pointer-events-auto" // Ensure mouse events are captured
      >
        <defs>
          {/* Define reusable glow filter - Simplified for performance */}
          <filter id="synapseGlow" x="-50%" y="-50%" width="200%" height="200%">
            <feGaussianBlur
              stdDeviation={theme === "dark" ? "2" : "1.5"}
              result="coloredBlur"
            />
          </filter>
          {/* Subtle radial gradient for background depth */}
          <radialGradient id="bgGradient" cx="50%" cy="50%" r="70%">
            <stop
              offset="0%"
              stopColor={
                theme === "dark"
                  ? "rgba(20, 10, 40, 0.1)"
                  : "rgba(230, 230, 240, 0.1)"
              }
            />
            <stop
              offset="100%"
              stopColor={
                theme === "dark"
                  ? "rgba(10, 5, 20, 0)"
                  : "rgba(200, 200, 210, 0)"
              }
            />
          </radialGradient>
        </defs>
        {/* Apply radial gradient background */}
        <rect
          width="100%"
          height="100%"
          fill={theme === "dark" ? "#0a0514" : "#f9fafb"}
        />{" "}
        {/* Solid base color */}
        <rect
          width="100%"
          height="100%"
          fill="url(#bgGradient)"
          opacity="0.5"
        />
        {/* Render Connections and Nodes using memoized components */}
        <ConnectionLines connections={connections} nodes={nodesRef.current} />
        <Nodes nodes={nodesRef.current} />
      </svg>

      {/* Central Content */}
      <div className="container mx-auto px-4 z-10 relative text-center flex flex-col items-center pointer-events-none mt-8 sm:mt-0">
        {/* Profile Image - Highly Optimized for LCP */}
        <div
          className="mb-4 sm:mb-8 pointer-events-auto opacity-100 scale-100 animate-quick-fade mt-4 sm:mt-0"
          style={{
            position: "relative",
            filter: `drop-shadow(0 0 15px rgba(100, 100, 255, 0.5))`,
            willChange: "transform",
            containIntrinsicSize: "300px",
            contentVisibility: "auto",
          }}
        >
          {/* Using profile image component */}
          <ProfileImage
            size={
              viewportWidth < 640 ? 240 : 300
            } /* Doubled size for both mobile/desktop */
            className="cursor-pointer"
          />
        </div>
        {/* Text Content - Using regular divs with CSS animation for faster LCP */}
        <div
          className="pointer-events-auto animate-fade-in w-full"
          style={{ animationDelay: "200ms" }}
        >
          <h1
            className={`text-3xl sm:text-4xl md:text-6xl font-bold mb-3 md:mb-4 ${
              theme === "dark" ? "text-gray-100" : "text-gray-900"
            } animate-fade-up`}
            style={{
              textShadow:
                theme === "dark"
                  ? "0 0 10px rgba(255,255,255,0.3)"
                  : "0 0 10px rgba(0,0,0,0.1)",
              animationDelay: "300ms",
            }}
          >
            Vetle Haakestad
          </h1>

          <p
            className={`text-base sm:text-lg md:text-xl max-w-xl sm:max-w-2xl mx-auto mb-6 sm:mb-8 px-2 ${
              theme === "dark" ? "text-gray-300" : "text-gray-600"
            } animate-fade-up`}
            style={{ animationDelay: "400ms" }}
          >
            Teknologientusiast med lang erfaring innen industriautomasjon og en
            nyfunnet lidenskap innen fullstack webutvikling.
          </p>

          <p
            className={`text-base sm:text-lg md:text-xl max-w-xl sm:max-w-2xl mx-auto mb-6 sm:mb-8 px-2 ${
              theme === "dark" ? "text-gray-300" : "text-gray-600"
            } animate-fade-up`}
            style={{ animationDelay: "400ms" }}
          >
            Min reise fra PLS-programmering til moderne AI og webutvikling gir
            et unikt perspektiv på hvordan teknologi kan transformere
            tradisjonelle virksomheter.
          </p>

          {/* Buttons - better spacing on mobile */}
          <div
            className="flex flex-col sm:flex-row justify-center gap-3 sm:gap-4 px-4 sm:px-0 animate-fade-up"
            style={{ animationDelay: "500ms" }}
          >
            <Button
              asChild
              variant="gradient"
              size={viewportWidth < 640 ? "default" : "lg"}
              className="bg-opacity-80 backdrop-blur-sm hover:bg-opacity-90 transition-all w-full sm:w-auto"
            >
              <Link href="/om-oss">Les om min historie!</Link>
            </Button>
            <Button
              asChild
              variant={theme === "dark" ? "outlineDark" : "outlineLight"}
              size={viewportWidth < 640 ? "default" : "lg"}
              className="bg-opacity-40 backdrop-blur-sm bg-background hover:bg-opacity-60 transition-all w-full sm:w-auto"
            >
              <Link href="/prosjekter">Se mine prosjekter</Link>
            </Button>
          </div>

          {/* Animated code terminal - better mobile experience 
          <div 
            className="mt-6 sm:mt-10 w-full max-w-full sm:max-w-2xl mx-auto animate-fade-up px-2 sm:px-0"
            style={{ animationDelay: '600ms' }}
          >
            <div className="mb-4 sm:mb-8 bg-black/30 backdrop-blur-sm rounded-md border border-cyan-900/40 p-2 sm:p-3 font-mono text-xs sm:text-sm overflow-hidden">
              <div className="flex items-center text-gray-500 text-xs mb-1 sm:mb-2">
                <div className="flex space-x-1.5 mr-2">
                  <div className="w-2 h-2 rounded-full bg-red-500/50"></div>
                  <div className="w-2 h-2 rounded-full bg-yellow-500/50"></div>
                  <div className="w-2 h-2 rounded-full bg-green-500/50"></div>
                </div>
                <span>terminal</span>
              </div>
              <div className="text-gray-300 flex items-center overflow-x-auto">
                <span className="text-green-400 mr-2 flex-shrink-0">$</span>
                <TypingAnimation 
                  text={viewportWidth < 640 ? "creating digital_experiences" : "creating digital_experiences --type=premium --location=norway"}
                  typingSpeed={35}
                  className="text-cyan-100 whitespace-nowrap overflow-hidden"
                />
              </div>
            </div>
          </div>
          */}
        </div>
      </div>
    </section>
  );
};

export default Hero;
